==> te-2.2.3.zip: te/plugins.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2010 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['no'] = 'కాదు';
$GLOBALS['__l10n']['blog settings'] = 'బ్లాగు అమరికలు';
$GLOBALS['__l10n']['Value'] = 'విలువ';
$GLOBALS['__l10n']['Description'] = 'వివరణ';
$GLOBALS['__l10n']['days'] = 'రోజులు';
$GLOBALS['__l10n']['Add'] = 'చేర్చు';
$GLOBALS['__l10n']['IP list'] = 'IPల జాబితా';
$GLOBALS['__l10n']['List'] = 'జాబితా';
$GLOBALS['__l10n']['No description'] = 'వివరణ లేదు';
$GLOBALS['__l10n']['Information'] = 'సమాచారం';
$GLOBALS['__l10n']['Order'] = 'క్రమం';
$GLOBALS['__l10n']['Filter name'] = 'వడపోత పేరు';
$GLOBALS['__l10n']['Blogroll'] = 'బ్లాగ్మిత్రులు';
$GLOBALS['__l10n']['manage blogroll'] = 'బ్లాగ్మిత్రులను సంభాళించండి';
$GLOBALS['__l10n']['Links'] = 'లంకెలు';
$GLOBALS['__l10n']['All categories'] = 'అన్ని వర్గాలు';
$GLOBALS['__l10n']['Return to blogroll'] = 'తిరిగి బ్లాగ్మిత్రులకి';
$GLOBALS['__l10n']['Edit category'] = 'పేజీ మార్పు';
$GLOBALS['__l10n']['_xfn_Family'] = 'కుటుబం';
$GLOBALS['__l10n']['_xfn_Child'] = 'బిడ్డ';
$GLOBALS['__l10n']['_xfn_Sibling'] = 'సహోదరి';
$GLOBALS['__l10n']['Lang'] = 'భాష';
$GLOBALS['__l10n']['Save order'] = 'క్రమం';
$GLOBALS['__l10n']['General'] = 'సాధారణ';
$GLOBALS['__l10n']['center'] = 'మధ్య';
$GLOBALS['__l10n']['left'] = 'ఎడమ';
$GLOBALS['__l10n']['right'] = 'కుడి';
$GLOBALS['__l10n']['Preview'] = 'మునుజూపు';
$GLOBALS['__l10n']['Sidebar'] = 'ప్రక్కపట్టీ';
$GLOBALS['__l10n']['Sidebar position:'] = 'ప్రక్కపట్టీ స్థానం:';
$GLOBALS['__l10n']['Sidebar text font:'] = 'ప్రక్కపట్టీ పాఠ్య ఖతి:';
$GLOBALS['__l10n']['Sidebar text color:'] = 'ప్రక్కపట్టీ పాఠ్యపు రంగు:';
$GLOBALS['__l10n']['The \'public\' directory does not exist.'] = 'ఈ పేజీ లేనే లేదు.';
$GLOBALS['__l10n']['Congratulation!'] = 'అభినందనలు!';
$GLOBALS['__l10n']['or'] = 'లేదా';
$GLOBALS['__l10n']['General information'] = 'సాధారణ సమాచారం';
$GLOBALS['__l10n']['Entries import options'] = 'టపాల దిగుమతి ఎంపికలు';
$GLOBALS['__l10n']['Importing users'] = 'వాడుకరులను దిగుమతిస్తున్నాం';
$GLOBALS['__l10n']['Importing categories'] = 'వర్గాలని దిగుమతిస్తున్నాం';
$GLOBALS['__l10n']['Importing blogroll'] = 'బ్లాగ్మిత్రులని దిగుమతిస్తున్నాం';
$GLOBALS['__l10n']['Send'] = 'పంపించు';
$GLOBALS['__l10n']['Please wait...'] = 'దయచేసి వేచివుండండి...';
$GLOBALS['__l10n']['next'] = 'తర్వాత';
$GLOBALS['__l10n']['Back'] = 'వెనక్కి';
$GLOBALS['__l10n']['Pages'] = 'పేజీలు';
$GLOBALS['__l10n']['manage pages'] = 'పేజీలను సంభాళించండి';
$GLOBALS['__l10n']['Published on'] = 'ప్రచురణ సమయం';
$GLOBALS['__l10n']['Page title'] = 'పేజీ శీర్షిక';
$GLOBALS['__l10n']['Page position'] = 'పేజీ స్థానం';
$GLOBALS['__l10n']['Publication date'] = 'ప్రచురణ తేదీ';
$GLOBALS['__l10n']['No page'] = 'పేజీ లేదు';
$GLOBALS['__l10n']['Are you sure you want to delete selected pages?'] = 'ఈ పేజీని మీరు నిజంగానే తొలగించాలనుకుంటున్నారా?';
$GLOBALS['__l10n']['New page'] = 'కొత్త పేజీ';
$GLOBALS['__l10n']['Selected pages action:'] = 'ఎంచుకున్న పేజీలపై చర్య:';
$GLOBALS['__l10n']['This page does not exist.'] = 'ఈ పేజీ లేనే లేదు.';
$GLOBALS['__l10n']['Edit page'] = 'పేజీ మార్పు';
$GLOBALS['__l10n']['next page'] = 'తర్వాతి పేజీ';
$GLOBALS['__l10n']['previous page'] = 'క్రితం పేజీ';
$GLOBALS['__l10n']['Are you sure you want to delete this page?'] = 'ఈ పేజీని మీరు నిజంగానే తొలగించాలనుకుంటున్నారా?';
$GLOBALS['__l10n']['Page has been successfully updated.'] = 'పేజీని విజయవంతంగా తాజాకరించాం.';
$GLOBALS['__l10n']['Page has been successfully created.'] = 'పేజీని విజయవంతంగా సృష్టించాం.';
$GLOBALS['__l10n']['View page'] = 'పేజీని చూడండి';
$GLOBALS['__l10n']['Preview page'] = 'పేజీ మునుజూపు';
$GLOBALS['__l10n']['Page status:'] = 'పేజీ స్థితి:';
$GLOBALS['__l10n']['Page position:'] = 'పేజీ స్థానం:';
$GLOBALS['__l10n']['Page lang:'] = 'పేజీ భాష:';
$GLOBALS['__l10n']['Page password:'] = 'పేజీ సంకేతపదం:';
$GLOBALS['__l10n']['Add files to this page'] = 'ఈ పేజీకి ఫైళ్ళను చేర్చండి';
$GLOBALS['__l10n']['error'] = 'పొరపాటు';
$GLOBALS['__l10n']['Tags'] = 'ట్యాగులు';
$GLOBALS['__l10n']['Tags:'] = 'ట్యాగులు:';
$GLOBALS['__l10n']['all'] = 'అన్నీ';
$GLOBALS['__l10n']['Tag'] = 'ట్యాగు';
$GLOBALS['__l10n']['entry'] = 'మధ్య';
$GLOBALS['__l10n']['entries'] = 'టపాలు';
$GLOBALS['__l10n']['Add tags'] = 'ట్యాగులను చేర్చండి';
$GLOBALS['__l10n']['Remove tags'] = 'ట్యాగులను తొలగించండి';
$GLOBALS['__l10n']['Add tags to entries'] = 'టపాలకు ట్యాగులను చేర్చండి';
$GLOBALS['__l10n']['Tags to add:'] = 'చేర్చాల్సిన ట్యాగులు:';
$GLOBALS['__l10n']['Tags list format:'] = 'చేర్చాల్సిన ట్యాగులు:';
$GLOBALS['__l10n']['Entries count'] = 'టపాల సంఖ్య';
$GLOBALS['__l10n']['Tag name'] = 'ట్యాగు పేరు';
$GLOBALS['__l10n']['All tags'] = 'అన్ని ట్యాగులూ';
$GLOBALS['__l10n']['No tags on this blog.'] = 'ఈ బ్లాగులో ట్యాగులేమీ లేవు.';
$GLOBALS['__l10n']['Theme Editor'] = 'అలంకార కూర్పరి';
$GLOBALS['__l10n']['No file'] = 'ఫైళ్ళు లేవు';
$GLOBALS['__l10n']['File does not exist.'] = 'ఫైలు లేనే లేదు.';
$GLOBALS['__l10n']['Presentation widgets'] = 'ప్రదర్శనా విడ్జెట్లు';
$GLOBALS['__l10n']['Blog languages'] = 'బ్లాగు భాషలు';
$GLOBALS['__l10n']['Somewhere else'] = 'మరెక్కడో';
$GLOBALS['__l10n']['Entries limit:'] = 'టపాల పరిమితి:';
$GLOBALS['__l10n']['Text'] = 'పాఠ్యం';
$GLOBALS['__l10n']['Text:'] = 'పాఠ్యం:';
$GLOBALS['__l10n']['Last entries'] = 'ఇటీవలి టపాలు';
$GLOBALS['__l10n']['Uncategorized'] = 'అవర్గీకృతం';
$GLOBALS['__l10n']['Last comments'] = 'ఇటీవలి వ్యాఖ్యలు';
$GLOBALS['__l10n']['Comments limit:'] = 'వ్యాఖ్యల పరిమితి:';
$GLOBALS['__l10n']['Entries feed'] = 'టపాల ఫీడు';
$GLOBALS['__l10n']['Comments feed'] = 'వ్యాఖ్యల ఫీడు';
$GLOBALS['__l10n']['Widgets'] = 'విడ్జెట్లు';
$GLOBALS['__l10n']['Available widgets'] = 'అందుబాటులో ఉన్న విడ్జెట్లు';
$GLOBALS['__l10n']['Setting name'] = 'అమరిక పేరు';
$GLOBALS['__l10n']['Setting value'] = 'అమరిక విలువ';
$GLOBALS['__l10n']['Setting name:'] = 'అమరిక పేరు:';
$GLOBALS['__l10n']['order'] = 'క్రమం';
?>

==> te-2.3.1.zip: te/plugins.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['no'] = 'కాదు';
$GLOBALS['__l10n']['blog settings'] = 'బ్లాగు అమరికలు';
$GLOBALS['__l10n']['Value'] = 'విలువ';
$GLOBALS['__l10n']['Description'] = 'వివరణ';
$GLOBALS['__l10n']['days'] = 'రోజులు';
$GLOBALS['__l10n']['Add'] = 'చేర్చు';
$GLOBALS['__l10n']['IP list'] = 'IPల జాబితా';
$GLOBALS['__l10n']['List'] = 'జాబితా';
$GLOBALS['__l10n']['No description'] = 'వివరణ లేదు';
$GLOBALS['__l10n']['Information'] = 'సమాచారం';
$GLOBALS['__l10n']['Order'] = 'క్రమం';
$GLOBALS['__l10n']['Filter name'] = 'వడపోత పేరు';
$GLOBALS['__l10n']['position'] = 'పేజీ స్థానం';
$GLOBALS['__l10n']['manage blogroll'] = 'బ్లాగ్మిత్రులను సంభాళించండి';
$GLOBALS['__l10n']['Links'] = 'లంకెలు';
$GLOBALS['__l10n']['All categories'] = 'అన్ని వర్గాలు';
$GLOBALS['__l10n']['Return to blogroll'] = 'తిరిగి బ్లాగ్మిత్రులకి';
$GLOBALS['__l10n']['Edit category'] = 'పేజీ మార్పు';
$GLOBALS['__l10n']['_xfn_Family'] = 'కుటుబం';
$GLOBALS['__l10n']['_xfn_Child'] = 'బిడ్డ';
$GLOBALS['__l10n']['_xfn_Sibling'] = 'సహోదరి';
$GLOBALS['__l10n']['Lang'] = 'భాష';
$GLOBALS['__l10n']['General'] = 'సాధారణ';
$GLOBALS['__l10n']['center'] = 'మధ్య';
$GLOBALS['__l10n']['left'] = 'ఎడమ';
$GLOBALS['__l10n']['right'] = 'కుడి';
$GLOBALS['__l10n']['Preview'] = 'మునుజూపు';
$GLOBALS['__l10n']['Sidebar'] = 'ప్రక్కపట్టీ';
$GLOBALS['__l10n']['Sidebar position:'] = 'ప్రక్కపట్టీ స్థానం:';
$GLOBALS['__l10n']['Sidebar text font:'] = 'ప్రక్కపట్టీ పాఠ్య ఖతి:';
$GLOBALS['__l10n']['Sidebar text color:'] = 'ప్రక్కపట్టీ పాఠ్యపు రంగు:';
$GLOBALS['__l10n']['The \'public\' directory does not exist.'] = 'ఈ పేజీ లేనే లేదు.';
$GLOBALS['__l10n']['Congratulation!'] = 'అభినందనలు!';
$GLOBALS['__l10n']['or'] = 'లేదా';
$GLOBALS['__l10n']['General information'] = 'సాధారణ సమాచారం';
$GLOBALS['__l10n']['Entries import options'] = 'టపాల దిగుమతి ఎంపికలు';
$GLOBALS['__l10n']['Importing users'] = 'వాడుకరులను దిగుమతిస్తున్నాం';
$GLOBALS['__l10n']['Importing categories'] = 'వర్గాలని దిగుమతిస్తున్నాం';
$GLOBALS['__l10n']['Importing blogroll'] = 'బ్లాగ్మిత్రులని దిగుమతిస్తున్నాం';
$GLOBALS['__l10n']['Send'] = 'పంపించు';
$GLOBALS['__l10n']['Please wait...'] = 'దయచేసి వేచివుండండి...';
$GLOBALS['__l10n']['next'] = 'తర్వాత';
$GLOBALS['__l10n']['Back'] = 'వెనక్కి';
$GLOBALS['__l10n']['New page'] = 'కొత్త పేజీ';
$GLOBALS['__l10n']['%d page'] = 'పేజీ మార్పు';
$GLOBALS['__l10n']['%d pages'] = 'పేజీ మార్పు';
$GLOBALS['__l10n']['manage pages'] = 'పేజీలను సంభాళించండి';
$GLOBALS['__l10n']['Published on'] = 'ప్రచురణ సమయం';
$GLOBALS['__l10n']['Page title'] = 'పేజీ శీర్షిక';
$GLOBALS['__l10n']['Page position'] = 'పేజీ స్థానం';
$GLOBALS['__l10n']['Publication date'] = 'ప్రచురణ తేదీ';
$GLOBALS['__l10n']['No page'] = 'పేజీ లేదు';
$GLOBALS['__l10n']['select this page'] = 'ఈ పేజీకి ఫైళ్ళను చేర్చండి';
$GLOBALS['__l10n']['Are you sure you want to delete selected pages?'] = 'ఈ పేజీని మీరు నిజంగానే తొలగించాలనుకుంటున్నారా?';
$GLOBALS['__l10n']['Selected pages action:'] = 'ఎంచుకున్న పేజీలపై చర్య:';
$GLOBALS['__l10n']['This page does not exist.'] = 'ఈ పేజీ లేనే లేదు.';
$GLOBALS['__l10n']['Edit page'] = 'పేజీ మార్పు';
$GLOBALS['__l10n']['next page'] = 'తర్వాతి పేజీ';
$GLOBALS['__l10n']['previous page'] = 'క్రితం పేజీ';
$GLOBALS['__l10n']['Are you sure you want to delete this page?'] = 'ఈ పేజీని మీరు నిజంగానే తొలగించాలనుకుంటున్నారా?';
$GLOBALS['__l10n']['Page has been successfully updated.'] = 'పేజీని విజయవంతంగా తాజాకరించాం.';
$GLOBALS['__l10n']['Page has been successfully created.'] = 'పేజీని విజయవంతంగా సృష్టించాం.';
$GLOBALS['__l10n']['View page'] = 'పేజీని చూడండి';
$GLOBALS['__l10n']['Preview page'] = 'పేజీ మునుజూపు';
$GLOBALS['__l10n']['Page status:'] = 'పేజీ స్థితి:';
$GLOBALS['__l10n']['Page position:'] = 'పేజీ స్థానం:';
$GLOBALS['__l10n']['Page lang:'] = 'పేజీ భాష:';
$GLOBALS['__l10n']['Page password:'] = 'పేజీ సంకేతపదం:';
$GLOBALS['__l10n']['Add files to this page'] = 'ఈ పేజీకి ఫైళ్ళను చేర్చండి';
$GLOBALS['__l10n']['error'] = 'పొరపాటు';
$GLOBALS['__l10n']['Tags'] = 'ట్యాగులు';
$GLOBALS['__l10n']['Tags:'] = 'ట్యాగులు:';
$GLOBALS['__l10n']['all'] = 'అన్నీ';
$GLOBALS['__l10n']['Tag'] = 'ట్యాగు';
$GLOBALS['__l10n']['entry'] = 'మధ్య';
$GLOBALS['__l10n']['entries'] = 'టపాలు';
$GLOBALS['__l10n']['Add tags'] = 'ట్యాగులను చేర్చండి';
$GLOBALS['__l10n']['Remove tags'] = 'ట్యాగులను తొలగించండి';
$GLOBALS['__l10n']['Add tags to entries'] = 'టపాలకు ట్యాగులను చేర్చండి';
$GLOBALS['__l10n']['Tags to add:'] = 'చేర్చాల్సిన ట్యాగులు:';
$GLOBALS['__l10n']['Tags list format:'] = 'చేర్చాల్సిన ట్యాగులు:';
$GLOBALS['__l10n']['Entries count'] = 'టపాల సంఖ్య';
$GLOBALS['__l10n']['Tag name'] = 'ట్యాగు పేరు';
$GLOBALS['__l10n']['All tags'] = 'అన్ని ట్యాగులూ';
$GLOBALS['__l10n']['No tags on this blog.'] = 'ఈ బ్లాగులో ట్యాగులేమీ లేవు.';
$GLOBALS['__l10n']['Theme Editor'] = 'అలంకార కూర్పరి';
$GLOBALS['__l10n']['No file'] = 'ఫైళ్ళు లేవు';
$GLOBALS['__l10n']['File does not exist.'] = 'ఫైలు లేనే లేదు.';
$GLOBALS['__l10n']['Preferences successfully updated'] = 'పేజీని విజయవంతంగా తాజాకరించాం.';
$GLOBALS['__l10n']['Preferences definition successfully updated'] = 'పేజీని విజయవంతంగా తాజాకరించాం.';
$GLOBALS['__l10n']['Presentation widgets'] = 'ప్రదర్శనా విడ్జెట్లు';
$GLOBALS['__l10n']['Blog languages'] = 'బ్లాగు భాషలు';
$GLOBALS['__l10n']['Somewhere else'] = 'మరెక్కడో';
$GLOBALS['__l10n']['Entries limit:'] = 'టపాల పరిమితి:';
$GLOBALS['__l10n']['Text'] = 'పాఠ్యం';
$GLOBALS['__l10n']['Text:'] = 'పాఠ్యం:';
$GLOBALS['__l10n']['Last entries'] = 'ఇటీవలి టపాలు';
$GLOBALS['__l10n']['Uncategorized'] = 'అవర్గీకృతం';
$GLOBALS['__l10n']['Last comments'] = 'ఇటీవలి వ్యాఖ్యలు';
$GLOBALS['__l10n']['Comments limit:'] = 'వ్యాఖ్యల పరిమితి:';
$GLOBALS['__l10n']['Entries feed'] = 'టపాల ఫీడు';
$GLOBALS['__l10n']['Comments feed'] = 'వ్యాఖ్యల ఫీడు';
$GLOBALS['__l10n']['Widgets'] = 'విడ్జెట్లు';
$GLOBALS['__l10n']['Available widgets'] = 'అందుబాటులో ఉన్న విడ్జెట్లు';
$GLOBALS['__l10n']['Setting name'] = 'అమరిక పేరు';
$GLOBALS['__l10n']['Setting value'] = 'అమరిక విలువ';
$GLOBALS['__l10n']['Setting name:'] = 'అమరిక పేరు:';
$GLOBALS['__l10n']['order'] = 'క్రమం';
?>
